# Copyright 2017 Stratumn SAS. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

require 'http'

module AgentClient
  ##
  # Wrapper around HTTP.request that parses the response and raises on error
  module Request
    def get(*args)
      request(:get, *args)
    end

    def post(*args)
      result = request(:post, *args)

      if result['meta'] && result['meta']['errorMessage']
        raise result['meta']['errorMessage']
      end

      result
    end

    private

    def request(verb, *args)
      result = HTTP.request(verb, *args).parse

      raise result['error'] if result.is_a?(Hash) && result['error']

      result
    end
  end
end
